#
# spec file for package udisks2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?_udevrulesdir: %global _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d}

Name:           udisks2
Summary:        Disk Manager
License:        GPL-2.0+
Group:          System Environment/Daemons
Version:        2.6.5
Release:        lp150.1.13
Url:            https://github.com/storaged-project/udisks
Source0:        https://github.com/storaged-project/udisks/releases/download/udisks-%{version}/udisks-%{version}.tar.bz2

# Needed to build the man pages
BuildRequires:  chrpath
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gnome-common
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  libacl-devel
BuildRequires:  libgudev-1_0-devel
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(glib-2.0) >= 2.31.13
BuildRequires:  pkgconfig(libatasmart) >= 0.17
BuildRequires:  pkgconfig(polkit-agent-1) >= 0.92
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.92
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)

# Needed to pull in the system bus daemon
Requires:       dbus-1
# We need at least this version for bugfixes/features etc.
Requires:       libatasmart4
# For mount, umount, mkswap
Requires:       util-linux
# sgdisk is called by udisksd to modify the partition tables... thus a needed tool.
Requires:       gptfdisk
# For LUKS devices
Requires:       cryptsetup
# For ejecting removable disks
Requires:       eject

Requires:       libudisks2-0 = %{version}
Recommends:     %{name}-lang

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}

# For /proc/self/mountinfo, only available in 2.6.26 or higher
Conflicts:      kernel < 2.6.26

# Upstream First - Policy:
# Never add any patches to this package without the upstream commit id
# in the patch. Any patches added here without a very good reason to make
# an exception will be silently removed with the next version update.

%description
The Udisks project provides a daemon, tools and libraries to access and
manipulate disks, storage devices and technologies.

%package -n libudisks2-0
Summary:        Dynamic library to access the udisksd daemon
License:        LGPL-2.1+
Group:          System/Libraries
Recommends:     %{name} = %{version}

%description -n libudisks2-0
This package contains the dynamic library, which provides
access to the udisksd daemon.

%package -n typelib-1_0-UDisks-2_0
Summary:        UDisks Client Library, version 2 -- Introspection bindings
License:        LGPL-2.1+
Group:          System/Libraries

%description -n typelib-1_0-UDisks-2_0
udisks provides a daemon, D-Bus API and command line tools
for managing disks and storage devices.

This package provides the GObject Introspection bindings for
the UDisks client library.

%package devel
Summary:        Development files for lib%{name}
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       libudisks2-0 = %{version}

%description devel
This package contains the development files for the library lib%{name}, a
dynamic library, which provides access to the udisksd daemon.

%lang_package

%prep
%setup -q -n udisks-%{version}

%build
%configure            \
    --sysconfdir=/etc \
    --enable-gtk-doc
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}

find %{buildroot} -name \*.la -o -name \*.a | xargs rm

chrpath --delete %{buildroot}/%{_sbindir}/umount.udisks2
chrpath --delete %{buildroot}/%{_bindir}/udisksctl
chrpath --delete %{buildroot}/%{_libexecdir}/udisks2/udisksd

%find_lang udisks2

#we don't want to load storaged modules
rm -r %{buildroot}/etc/udisks2

%pre
%service_add_pre udisks2.service

%post -n %{name}
%{?udev_rules_update:%udev_rules_update}
%service_add_post udisks2.service

%post -n libudisks2-0 -p /sbin/ldconfig

%preun
%service_del_preun udisks2.service

%postun
%service_del_postun udisks2.service

%postun -n libudisks2-0 -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc README.md AUTHORS NEWS HACKING COPYING

%dir %{_libexecdir}/udisks2
%{_libexecdir}/udisks2/udisksd
%config %{_sysconfdir}/dbus-1/system.d/org.freedesktop.UDisks2.conf
%{_datadir}/bash-completion/completions/udisksctl
%{_unitdir}/udisks2.service
%dir %{_udevrulesdir}
%{_udevrulesdir}/80-udisks2.rules
%{_sbindir}/umount.udisks2

%dir %{_libexecdir}/udisks2
%{_libexecdir}/udisks2/udisksd

%{_bindir}/udisksctl

%{_mandir}/man1/udisksctl.1*
%{_mandir}/man5/udisks2.conf.5*
%{_mandir}/man8/udisksd.8*
%{_mandir}/man8/udisks.8*
%{_mandir}/man8/umount.udisks2.8*

%{_datadir}/polkit-1/actions/org.freedesktop.UDisks2.policy
%{_datadir}/dbus-1/system-services/org.freedesktop.UDisks2.service

# Permissions for local state data are 0700 to avoid leaking information
# about e.g. mounts to unprivileged users
%attr(0700,root,root) %dir %{_localstatedir}/lib/udisks2

%files -n libudisks2-0
%defattr(-,root,root,-)
%{_libdir}/libudisks2.so.*

%files -n typelib-1_0-UDisks-2_0
%defattr(-,root,root,-)
%{_libdir}/girepository-1.0/UDisks-2.0.typelib

%files devel
%defattr(-,root,root,-)
%{_libdir}/libudisks2.so
%dir %{_includedir}/udisks2
%dir %{_includedir}/udisks2/udisks
%{_includedir}/udisks2/udisks/*.h
%{_datadir}/gir-1.0/UDisks-2.0.gir

%doc %{_datadir}/gtk-doc/html/udisks2/
%{_libdir}/pkgconfig/udisks2.pc

%files lang -f udisks2.lang

%changelog
* Wed Jul  5 2017 Thomas.Blume@suse.com
- Update to version 2.6.5 (fate#323354)
  * switch to new maintained codestream at
    https://github.com/storaged-project/udisks
  * Detailed changelog in /usr/share/doc/packages/udisks2/NEWS
* Fri Dec  9 2016 dimstar@opensuse.org
- Update to version 2.1.8:
  + Allow NTFS mount option "big_writes".
  + Don't coldplug uninitilized udev devices.
  + Detect old (non-Pro) MemoryStick cards.
  + Lock the partition table while creating a new partition.
  + exfat: Drop umask=0077 default.
  + udisks2.service: Add KillSignal=SIGINT.
  + btrfs: Add support for changing label.
  + Updated translations.
- Replace pkgconfig(libsystemd-login) BuildRequires with
  pkgconfig(libsystemd): the two have been merged since
  systemd 209.
- Drop udisks2-Reread-partition-table-before-wiping.patch: fixed
  upstream.
* Fri Apr 15 2016 zaitor@opensuse.org
- Add udisks2-Reread-partition-table-before-wiping.patch: Reread
  partition table before wiping when creating new partitions
  (fdo#85477).
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 2.1.7:
  + Allow disabling ACL.
  + udisksctl: Properly redirect stdout.
  + Catch bogus UUID changes of MDRAIDs.
  + Fix udiskctl help for glib 2.45.
  + udisks2.service.in: Add [Install] section.
  + Fix translator comments in udisksobjectinfo.c.
  + integration-test: Explicitly require UDisks 2.0 typelib.
  + integration-test: Fix wait_timeout/busy error messages.
  + integration-test: PEP-8 fixes.
  + integration-test: Fix Polkit.test_removable_fs.
  + test_polkitd.py: Fix race condition in waiting for test
    polkitd.
  + integration-test: Fix race condition in fake CD drive creation.
  + integration-test: Add timeout to readd_device().
  + Add support for read look-ahead ATA settings (fdo#92488).
- Add tarball signing.
- Change group to System/Daemons.
* Thu Jul  9 2015 zaitor@opensuse.org
- Update to version 2.1.6:
  + udev rules: Stop hardcoding sed path.
  + Fix crash on inaccessible RAID member "state" attribute.
  + UDF: Drop umask=0077 default.
  + Install udisksd into a libexecdir.
  + Fail before formatting if partition contains a partition table.
  + Fix udisks_daemon_util_file_set_contents() return value
    handling.
  + Remove deprecated g_io_scheduler_* calls.
  + integration-tests:
  - Settle while waiting for property change.
  - Don't fail if a SMART test was aborted.
  - Add a wrapper to write and flush stderr.
  + Don't ignore isohybrid udf filesystems.
  + Add support for creating f2fs filesystems.
  + Decide whether devices are on the same seat by uid, not pid.
  + UDisksSpawnedJob: Retrieve uid/gid info before forking.
* Fri Mar  6 2015 sor.alexei@meowr.ru
- Update to 2.1.5:
  * configure: stop using tmpl files for docs.
  * docs: include the annotation glossary.
  * Drop default [df]mask for VFAT and NTFS.
  * Drop unused goto label.
  * Fix crash in udisks_client_finalize().
  * Fix format string signedness warnings.
  * integration-tests: Don't assume ordering in mount-points
    property.
  * integration-test: Skip double mount check for NTFS.
  * integration-test: Stop requiring the build dependencies.
  * integration-test: Test fstab parsing.
  * Make UdisksClient.get_size_for_display() units translatable.
  * Provide fallback for systems without ACL support.
  * Recognize PARTUUID and PARTLABEL in fstab.
  * Support mounting in /media for FHS compatibility.
  * Update translations.
- Add recommended /usr/sbin/rcudisks2 service alias.
- Remove obsolete definitions.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 2.1.4:
  + Add GPT partition types from the Discoverable Partitions
    Specification.
  + Remove newly-added "Auto-enabled swap" GTP partition type.
  + Fine-tune GTP partitions some more.
  + Send SCSI SYNCHRONIZE CACHE before powering down a drive.
  + Fix buffer overflow in pick_word_at().
  + Add Intel Fast Flash Standby partition GPT type.
  + Skip password strength checks when changing LUKS passphrase.
  + Fix build with clang.
  + Revert "Fix standby timers".
  + integration-test:
  - Update for logind.
  - Fix code formatting.
  - sync file systems in sync().
  - integration-test: Drop sync_workaround, fix property testing.
  - integration-test: Better failure messages.
  - integration-test: Fix btrfs test.
  + Fix display ID for generic FAT.
  + Update obsolete gnome-common and automake macros.
  + build:
  - Use config-aux/ directory.
  - Enable gcc colors.
  + Drop obsolete g_type_init().
  + Drop obsolete polkit_unix_process_new().
  + Fix docs for SmartUpdate().
  + Hide Microsoft reserved partition.
  + Identify JetFlash Transcend drives as thumb drives.
  + Fix sorting of mount points.
  + Fix fallback media icons for nonremovable media.
  + Fix polkit auth string.
  + Hide DIAGS and IntelRST partitions.
  + Add a man page for umount.udisks2.
  + Support building against libsystemd library.
  + udisks: Change name for Intel SW RAID.
  + Use internal pm check for smart poll.
  + Fix standby timers.
  + Fix TOCTOU race when making directories.
  + Add missing #include.
  + Properly initialize all used variables.
  + udiskslinuxmanager.c: Don't use uninitialized wait_data struct.
  + Remove useless assignments.
  + udisks_linux_drive_object_uevent(): Handle null device.
  + Hide Windows Recovery Environment partitions.
  + Updated translations.
* Mon Mar 10 2014 pwieczorkiewicz@suse.com
- Update to version 2.1.3:
  + Identify SD Card Reader in ChromeBook Pixel
  + Send SCSI START STOP UNIT when powering down a drive
  + udisksctl: add power-off verb to power off drives
  + udisksctl: fix grammar
  + Prefer /dev/VG/LV for LVM2 volumes.
  + Fix buffer overflow in mount path parsing. If users have
    the possibility to create very long mount points, such as
    with FUSE, they could cause udisksd to crash, or even to
    run arbitrary code as root with specially crafted mount paths.
    (bnc#865854, CVE-2014-0004)
  + Use SECTOR_COUNT=1 when issuing ATA IDENTIFY COMMAND
  + Use reentrant version of getpwuid() for thread safety
  + udisks_daemon_util_get_caller_uid_sync(): Add missing goto
  + Fix crash when loop-deleting non-loop device
* Sun Feb 16 2014 zaitor@opensuse.org
- Update to version 2.1.2:
  + Add exfat mount options.
  + Hide more rescue partitions.
  + Build fails due to missing IT_PROG_INTLTOOL macro (fdo#67679).
  + Add exfat FS integration test.
  + Drop "david" user name from publish make rules.
  + Use dosfstools instead of mtools.
  + Add polkit authorization variables for removable media.
  + Fix crash when waiting for loop device.
- Drop udisks2-20131026-removable-devices-polkit-auth.patch: fixed
  upstream.
* Tue Dec 10 2013 pwieczorkiewicz@suse.com
- Added udisks2-20131026-removable-devices-polkit-auth.patch.
  It adds polkit authorization variables for removable media, which
  allow restricting or granting access to removable media based on
  its type using polkit authorization rules (fate#312966 fdo#72122).
* Sun Nov 24 2013 crrodriguez@opensuse.org
- define _udevrulesdir only if not already defined
- run %%udev_rules_update, if defined.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 2.1.1:
  + Properly identify firewire devices as non-system devices.
  + Identify Lexar Dual Slot USB 3.0 Reader Professional as a card
    reader.
  + Identify Transcend USB 3.0 Multi-Card reader as such.
  + Promote ZFS partition type to generic.
  + UDisksClient: Make it possible to get part desc based on the
    part table subtype.
  + Add ChromeOS partition types.
  + Use new SSD icon from g-i-t-e.
  + Identify Patriot Memory USB sticks as thumb drives.
  + Fix test for logind availability.
  + Fix hiding of "WD SmartWare" partitions.
  + integration-test: Fix for nonexisting /run/udev/rules.d/.
  + integration-test: For VFAT, ignore case for label comparison.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 2.1.0:
  + mdraid: Remove spurious argument for the format.
  + Support broken setups where ID_SERIAL is available but
    ID_SERIAL_SHORT is not.
  + Call the right D-Bus completion routines.
  + integration-test: Update for mkntfs.
  + Updated translations.
* Sun Mar  3 2013 hrvoje.senjan@gmail.com
- Update to version 2.0.92:
  + Fix out of source build - set xsltproc path.
  + Fold UDisksPersistentStore class into UDisksCleanup.
  + Rename UDisksCleanup to UDisksState.
  + Don't leak UDisksLinuxDevice when handling uevent.
  + Check for NULL pointer when creating MD-RAID array.
  + Use own udev namespace for MD-RAID properties.
  + Introduce UDISKS_FILESYSTEM_SHARED=1 to use /media for
    mounting.
  + Don't wipe extended partitions.
  + Make sure logical partitions stay within the extended
    partition.
* Thu Jan 17 2013 dimstar@opensuse.org
- Update to version 2.0.91:
  + Don't bail in MD-RAID file monitor event handler.
  + Add MDRaid:RequestSyncAction() method.
  + Add MDRaid:SyncRate and MDRaid:SyncRemainingTime properties.
  + Get the MD-RAID sync rate from the right file.
  + Pull new translations from Transifex.
  + Use correct polkit action.
  + Fix up comments in polkit policy file.
- Changes from version 2.0.90:
  + Initial MD-RAID support.
- Drop fix_polkit_action_name.diff: it's not applied anyway.
* Thu Jan 17 2013 vuntz@opensuse.org
- Really apply fix_polkit_action_name.diff.
* Mon Jan  7 2013 stefan.bruens@rwth-aachen.de
- Fix name of polkit action (fdo#58629):
  modify-device-system-other-seat -> modify-device-other-seat
* Sun Jan  6 2013 dimstar@opensuse.org
- Add gptfdisk Requires: sgdisk is called by udisksd to modify the
  partition tables (bnc#796853).
* Mon Nov 12 2012 hrvoje.senjan@gmail.com
- Update to version 2.0.0
  + configure.ac: raise gudev dependency
  + Add --disable-man configure option
  + Update list of recovery/system partitions
  + Add support for creating exFAT filesystems and changing exFAT
    labels
  + Add textual descriptions for IMSM Raid members
  + Use all-caps for RAID
  + Only do the isohybrid hack for the first partition
  + Don't complain about missing /etc/crypttab file
  + Don't complain about missing /etc/fstab file
  + Make it work without requiring the kernel to be CONFIG_SWAP=y
  + Mention the right file when complaing about /proc/swaps
  + Fix glaringly wrong documentation for Filesystem.Mount()
  + Move bash completion script into
    /usr/share/bash-completion/completions
  + Don't require that users define UDISKS_API_IS_SUBJECT_TO_CHANGE
  + Remove udisks_daemon_util_on_other_seat() from sections.txt
  + Add workaround annotation for
    udisks_client_get_block_for_dev()
  + Enable large file support
  + Various doc and tests fixes
  + Bugs fixed: fdo#51063.
  + Updated translations.
- Drop systemd-dynamic-check.diff: fixed upstream.
- Dropped gnome-common BuildRequires and call to gnome-autogen.sh,
  as the patch which needed that is dropped.
* Wed Oct 24 2012 meissner@suse.com
- remove the rpmlintrc after adding the privs bnc#779404
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new udev rules directory location.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 1.99.0:
  + Catch up with latest polkit guidance
  + Don't require auth for Standby'ing non-system drives on own
    seat
  + Mark Realtek rts5229 based card readers as flash drives
  + Black-list seemingly invalid WWN for SAMSUNG SP1604N hard disks
  + Ignore non-Linux software on SanDisk Cruzer
  + Add drive configuration interfaces and configuration files
  + Add "Linux Filesystem" GPT partition type
  + Add support for VMWare filesystem types and GPT partition types
  + Update integration tests.
  + Bugs fixed:
  - fdo#51439: udisks should hide lvm PVs
- Changes from version 1.98.0:
  + Drive: Refuse to eject drives that appear to be in use
  + udisksd: work if polkitd is not available
  + Updated documentations
  + Bugs fixed:
  - fdo49842: Unhandled rootfs on bind mount
- Drop udisks-hide-lvm-raid-partitions.patch: fixed upstream.
* Tue Sep 25 2012 vuntz@opensuse.org
- Update systemd-dynamic-check.diff with patch sent upstream.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  needed by the patch now.
* Tue Jul  3 2012 tiwai@suse.de
- Add systemd-dynamic-check.diff: add a check of running systemd
  (bnc#769570)
* Tue Jun 26 2012 gber@opensuse.org
- Added udisks-hide-lvm-raid-partitions.patch in order to hide
  partitions marked as containing LVM and RAID. This is only useful
  for encrypted partitions (fixes fdo#51439 and bnc#737038).
* Fri May 11 2012 vuntz@opensuse.org
- Update to version 1.97.0:
  + Several improvements for loop devices
  + Also check for "target is busy" when checking umount(8) output
  + UDisksCleanup: Remove stale entries when adding new ones
  + Add work-around to show FS on CDs/USB sticks created using
    isohybrid
  + Several code improvements
  + Update path to mounted-fs file in documentation
- Changes from version 1.96.0:
  + Actually link with libsystemd-login
- Changes from version 1.95.0:
  + Add multi-seat support
  + Add versioning macros
  + Use libacl library instead of setfacl(1)
  + Work around missing serial/wwn on VMware hard disks
  + Add separate polkit actions for ejecting media
  + Make $(udisks2.device) in authentication messages include the
    vendor/model
  + Remove unused .filesystem-unmount-others-shared polkit action
  + Documentation fixes and improvements
  + Updated translations
- Add libacl-devel BuildRequires: it's now really used.
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.94.0:
  + Pass --readonly to cryptsetup(8) if device to unlock is
    read-only
  + Add udev rules for identifying devices which should not be
    shown
  + Fix unmounting large disks when not asked to
  + Make escaping work properly with non-ASCII UTF-8 strings
  + Change some D-Bus types from bytestring ('ay') to UTF8 ('s')
  + Convert some g_warning() uses to udisks_warning()
  + Improved documentation.
* Tue Mar  6 2012 vuntz@opensuse.org
- Update to version 1.93.0:
  + Force MediaRemovable to TRUE for e.g. SD cards using the mmc
    layer
  + Ensure that whatever we pass as -t to mount(8) is in a
    whitelist
  + Ensure that the loop file name we pass to the kernel is always
    NUL-terminated
  + Properly escape all device files
  + Improved documentation.
- Remove libacl-devel BuildRequires: not needed anymore.
* Mon Feb 27 2012 vuntz@opensuse.org
- Update to version 1.92.0:
  + client: Fix bit shifts of flags on 32 bit
  + Avoid using $XDG_RUNTIME_DIR/media for now
  + Don't free object twice when deleting a loop device
  + Use /run/media/$USER for mounting
  + Move to /usr-only setup and get rid of hardcoded paths to /lib
    and sbin
- Changes from version 1.91.0:
  + Install a systemd service file if systemd is used
  + Ensure PATH is set
  + Fix use of memset(3)
  + Use org.freedesktop.UDisks2.* for errors, not
    org.freedesktop.UDisks.*
  + For mount options, switch from comment=udisks to x-udisks
  + Prefer mounting in /run/user/$USER/media instead of /media
  + With /media and /run on tmfs, switch to temporary store for
    mounted-fs
  + Make sure that Drive:SortKey sorts e.g. sdz before sdaa
  + Do coldplug for block devices twice
  + Use g_dbus_interface_dup_object() and check return value
  + Shut up valgrind complaing about LOOP_GET_STATUS64 ioctl
  + Fix a couple of uninitialized warnings and simplify SMART
    self-test handling
  + udisksctl:
  - nuke PORT column in output of 'status' verb
  - sort the drives using Drive:SortKey for 'status' verb
  + Documentation fixes.
  + Build fixes.
  + Updated translations.
- Add systemd-related packaging:
  + Add pkgconfig(systemd) BuildRequires.
  + Use %%{?systemd_requires}.
  + Call %%service_{add,del}_* macros in scriptlets for
    udisks2.service.
- Add pkgconfig(udev) BuildRequires, now needed to find right path
  for udev files.
- Add libacl-devel BuildRequires, now needed.
* Sat Jan 21 2012 vuntz@opensuse.org
- New udisks2 source package, based on udisks source package.
- First version (1.90.0).
- udisks 2.x is parallel-installable with udisks 1.x.
